
function love.run()

	if love.math then
		love.math.setRandomSeed(os.time())
	end

	if love.load then love.load(arg) end

	-- We don't want the first frame's dt to include time taken by love.load.
	if love.timer then love.timer.step() end

	local dt = 0

	-- Main loop time.
	while true do
		-- Process events.
		if love.event then
			love.event.pump()
			for name, a,b,c,d,e,f in love.event.poll() do
				if name == "quit" then
					if not love.quit or not love.quit() then
						return a
					end
				end
				love.handlers[name](a,b,c,d,e,f)
			end
		end

		-- Update dt, as we'll be passing it to update
		if love.timer then
			love.timer.step()
			dt = love.timer.getDelta()
		end

		-- Call update and draw
		if love.update then love.update(dt) end -- will pass 0 if love.timer is disabled

		if love.graphics and love.graphics.isActive() then
			love.graphics.clear(love.graphics.getBackgroundColor())
			love.graphics.origin()
			if love.draw then love.draw() end
			love.graphics.present()
		end

		if love.timer then love.timer.sleep(0.001) end
	end

end

function love.load()
  x = 0
  y = 0
  love.window.setMode(1280, 720, {resizable=true, vsync=true})
end

function love.update(dt)
  local XX, YY = love.mouse.getPosition()
  if y + 50 > YY then y = y - 200 * dt end
  if y + 50 < YY then y = y + 200 * dt end
  if x + 50 > XX then x = x - 200 * dt end
  if x + 50 < XX then x = x + 200 * dt end
  love.window.setTitle(1/dt)
end

function love.draw()
  love.graphics.setColor(255, 255, 255, 255)
  love.graphics.rectangle("fill", x, y, 100, 100)
end
